[PATCH 5/5] SQUASHME: spnfs: use only RETURN_* constants

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Signed-off-by: Benny Halevy <bhalevy@xxxxxxxxxxx>
---
 fs/nfsd/spnfs_ops.c |   14 +++++++-------
 1 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/fs/nfsd/spnfs_ops.c b/fs/nfsd/spnfs_ops.c
index 322fc12..2838a85 100644
--- a/fs/nfsd/spnfs_ops.c
+++ b/fs/nfsd/spnfs_ops.c
@@ -199,17 +199,17 @@ spnfs_layoutrecall(struct inode *inode, int type, u64 offset, u64 len)
 	struct nfsd4_pnfs_cb_layout lr;
 
 	switch (type) {
-	case RECALL_FILE:
+	case RETURN_FILE:
 		sb = inode->i_sb;
 		dprintk("%s: recalling layout for ino = %lu\n",
 			__func__, inode->i_ino);
 		break;
-	case RECALL_FSID:
+	case RETURN_FSID:
 		sb = inode->i_sb;
 		dprintk("%s: recalling layout for fsid x (unimplemented)\n",
 			__func__);
 		return 0;
-	case RECALL_ALL:
+	case RETURN_ALL:
 		/* XXX figure out how to get a sb since there's no inode ptr */
 		dprintk("%s: recalling all layouts (unimplemented)\n",
 			__func__);
@@ -244,19 +244,19 @@ spnfs_test_layoutrecall(char *path, u64 offset, u64 len)
 
 	if (strcmp(path, "all") == 0) {
 		inode = NULL;
-		type = RECALL_ALL;
+		type = RETURN_ALL;
 	} else {
 		rc = path_lookup(path, 0, &nd);
 		if (rc != 0)
 			return -ENOENT;
 
 		/*
 		 * XXX todo: add a RECALL_FSID scenario here...maybe if
 		 * inode is a dir...
 		 */
 
 		inode = nd.path.dentry->d_inode;
-		type = RECALL_FILE;
+		type = RETURN_FILE;
 	}
 
 	if (len == 0)
@@ -264,7 +264,7 @@ spnfs_test_layoutrecall(char *path, u64 offset, u64 len)
 
 	rc = spnfs_layoutrecall(inode, type, offset, len);
 
-	if (type != RECALL_ALL)
+	if (type != RETURN_ALL)
 		path_put(&nd.path);
 	return rc;
 }
@@ -244,19 +244,19 @@ spnfs_test_layoutrecall(char *path, u64 offset, u64 len)
 
 		/*
-		 * XXX todo: add a RECALL_FSID scenario here...maybe if
+		 * XXX todo: add a RETURN_FSID scenario here...maybe if
 		 * inode is a dir...
 		 */
-- 
1.6.5.1

--
To unsubscribe from this list: send the line "unsubscribe linux-fsdevel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Linux Ext4 Filesystem]     [Union Filesystem]     [Filesystem Testing]     [Ceph Users]     [Ecryptfs]     [AutoFS]     [Kernel Newbies]     [Share Photos]     [Security]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux Cachefs]     [Reiser Filesystem]     [Linux RAID]     [Samba]     [Device Mapper]     [CEPH Development]
  Powered by Linux